import { defineConfig, loadEnv } from 'vite'
import vue from '@vitejs/plugin-vue'
import vueJsx from '@vitejs/plugin-vue-jsx'
import path from 'path'
import { fileURLToPath } from 'url'
import components from 'unplugin-vue-components/vite';
import { AntDesignXVueResolver } from 'ant-design-x-vue/resolver';
const __dirname = path.dirname(fileURLToPath(import.meta.url))

function resolve(dir) {
    return path.join(__dirname, dir)  
}

export default defineConfig(({ command, mode }) => {
  // 加载env文件
  const env = loadEnv(mode, process.cwd(), '')
  
  return {
    plugins: [
      components({
        resolvers: [AntDesignXVueResolver()],
      }),
      vue(),
      vueJsx()
    ],
    resolve: {
      alias: {
        '@': resolve('src'),
        '@api': resolve('src/api'),
        '@assets': resolve('src/assets'),
        '@layouts': resolve('src/layouts'),
        '@static': resolve('src/static'),
        '@components': resolve('src/components'),
        '@router': resolve('src/router'),
        '@utils': resolve('src/utils'),
        '@store': resolve('src/store'),
        '@views': resolve('src/views')
      },
      extensions: ['.js', '.jsx', '.ts', '.tsx', '.json', '.vue']
    },
    server: {
      host: true,
      port: 8003,
      proxy: {
        '/WebSocketConfig/': {
          target: 'ws://test.com',
          changeOrigin: true,
          ws: true,
        },
        '/api/': {
          target: 'http://test.com',
          changeOrigin: true,
          ws: false,
        }
      }
    },
    base: './',
    build: {
      sourcemap: true,
      rollupOptions: {
        output: {
          manualChunks: undefined
        }
      }
    }
  }
})